@@ -1,6 +1,6 @@
 package Catmandu::Exporter::XLSX;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use namespace::clean;
 use Catmandu::Sane;
@@ -96,8 +96,8 @@ Catmandu::Exporter::XLSX - a XLSX exporter
 
     my $exporter = Catmandu::Exporter::XLSX->new(
                 file => 'test.xlsx',
-                fields => 'a,b,c'
-                columns => 'ALPHA,BRAVO,CHARLIE'
+                fields => 'a,b,c',
+                columns => 'ALPHA,BRAVO,CHARLIE',
                 header => 1);
 
     $exporter->add({a => 1, b => 2, c => 3});
@@ -134,7 +134,7 @@ comma-separated string
 
 =item columns
 
-List of custom culomn names, given as array reference or comma-separated 
+List of custom column names, given as array reference or comma-separated 
 list. 
  
 =back
